@@ -788,16 +788,17 @@ main(int  argc,				/* I - Number of command-line args */
     * will not compress the pages, so that the PostScript code can get
     * analysed. This is especially important if a PostScript printer errors or
     * misbehaves on Ghostscript's output.
-    * On Kyocera printers we always suppress page compression, to avoid slow
-    * processing of raster images.
+    * On Kyocera and Utax (uses Kyocera hard- and software) printers we always
+    * suppress page compression, to avoid slow processing of raster images.
     */
     val = cupsGetOption("psdebug", num_options, options);
     if ((val && strcasecmp(val, "no") && strcasecmp(val, "off") &&
 	 strcasecmp(val, "false")) ||
 	(make_model[0] &&
-	 !strncasecmp(make_model, "Kyocera", 7)))
+	 (!strncasecmp(make_model, "Kyocera", 7) ||
+	  !strncasecmp(make_model, "Utax", 4))))
     {
-      fprintf(stderr, "DEBUG: Deactivated compression of pages in Ghostscript's PostScript output (\"psdebug\" debug mode or Kyocera printer)\n");
+      fprintf(stderr, "DEBUG: Deactivated compression of pages in Ghostscript's PostScript output (\"psdebug\" debug mode or Kyocera/Utax printer)\n");
       pdf_argv[pdf_argc++] = (char *)"-dCompressPages=false";
     }
    /*
@@ -854,6 +855,7 @@ main(int  argc,				/* I - Number of command-line args */
     need_post_proc =
       (make_model[0] &&
        (!strncasecmp(make_model, "Kyocera", 7) ||
+	!strncasecmp(make_model, "Utax", 4) ||
 	!strncasecmp(make_model, "Brother", 7)) ? 1 : 0);
   else
     need_post_proc = 1;
@@ -1033,12 +1035,12 @@ main(int  argc,				/* I - Number of command-line args */
 	  {
 
 	   /*
-	    * Kyocera printers have a bug in their PostScript interpreter
-	    * making them crashing on PostScript input data generated by
-	    * Ghostscript's "ps2write" output device.
+	    * Kyocera (and Utax) printers have a bug in their PostScript
+	    * interpreter making them crashing on PostScript input data
+	    * generated by Ghostscript's "ps2write" output device.
 	    *
-	    * The problem can be simply worked around by preceding the PostScript
-	    * code with some extra bits.
+	    * The problem can be simply worked around by preceding the
+	    * PostScript code with some extra bits.
 	    *
 	    * See https://bugs.launchpad.net/bugs/951627
 	    *
@@ -1049,14 +1051,15 @@ main(int  argc,				/* I - Number of command-line args */
 	    * See https://bugs.launchpad.net/bugs/1026974
 	    */
 
-	    if (!strncasecmp(make_model, "Kyocera", 7))
+	    if (!strncasecmp(make_model, "Kyocera", 7) ||
+		!strncasecmp(make_model, "Utax", 4))
 	    {
-	      fprintf(stderr, "DEBUG: Inserted workaround PostScript code for Kyocera printers\n");
+	      fprintf(stderr, "DEBUG: Inserted workaround PostScript code for Kyocera and Utax printers\n");
 	      puts("% ===== Workaround insertion by pdftops CUPS filter =====");
-	      puts("% Kyocera's PostScript interpreter crashes on early name binding,");
+	      puts("% Kyocera's/Utax's PostScript interpreter crashes on early name binding,");
 	      puts("% so eliminate all \"bind\"s by redefining \"bind\" to no-op");
 	      puts("/bind {} bind def");
-	      puts("% Some Kyocera printers have an unacceptably slow implementation");
+	      puts("% Some Kyocera and Utax printers have an unacceptably slow implementation");
 	      puts("% of image interpolation.");
 	      puts("/image");
 	      puts("{");
